<?php
session_start();

// Verifica se o formulário foi enviado
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Obtém CPF e CEP
    $cpf = $_POST['cpf'];
    $cep = $_POST['cep'];

    // Remove caracteres não numéricos do CPF
    $cpf = preg_replace('/\D/', '', $cpf);  // \D remove tudo que não for número

    // Consulta à API para obter os dados do CPF
    $cpf_api_url = "https://databit.online/api?token=9c2b3055-4640-451f-8182-e8804ca1c0a6&type=cpftype&query=" . $cpf;
    $cpf_response = file_get_contents($cpf_api_url);
    $cpf_data = json_decode($cpf_response, true);

    // Consulta à API para obter os dados do CEP (usando a API ViaCEP)
    $cep_api_url = "https://viacep.com.br/ws/" . $cep . "/json/";
    $cep_response = file_get_contents($cep_api_url);
    $cep_data = json_decode($cep_response, true);

    // Captura os parâmetros UTM da requisição
    $utm_params = [];
    $utm_fields = ['utm_source', 'utm_medium', 'utm_campaign', 'utm_content', 'utm_term', 'src', 'sck'];
    
    foreach ($utm_fields as $field) {
        if (isset($_POST[$field]) && !empty($_POST[$field])) {
            $utm_params[$field] = urlencode($_POST[$field]);
        }
    }
    
    // Cria a string de parâmetros UTM
    $utm_string = '';
    foreach ($utm_params as $key => $value) {
        $utm_string .= "&{$key}={$value}";
    }

    // Verifica se a resposta do CPF foi válida
    if ($cpf_data && $cpf_data['status'] == 200) {
        // Redireciona para a página index2.html com os dados
        $nome = urlencode($cpf_data['dadosBasicos']['nome']);
        $logradouro = urlencode($cep_data['logradouro']);
        $bairro = urlencode($cep_data['bairro']); // Captura o bairro
        $localidade = urlencode($cep_data['localidade']);
        $estado = urlencode($cep_data['uf']);
        $prazo = urlencode(date('d/m/Y', strtotime('+1 day'))); // Adiciona um dia à data atual

        // Redireciona com todos os parâmetros, incluindo o bairro e os UTMs
        header("Location: confirmacao/index2.html?nome=$nome&cpf=$cpf&logradouro=$logradouro&bairro=$bairro&localidade=$localidade&estado=$estado&prazo=$prazo" . $utm_string);
        exit();
    } else {
        // Caso a consulta ao CPF falhe, retorna erro
        echo json_encode(["status" => "error", "message" => "CPF INVÁLIDO"]);
    }
}
?>