<?php
// Script para verificar e sincronizar vendas aprovadas com o UTMify
// Este script pode ser executado periodicamente (ex: a cada 15 minutos) para garantir que todas as vendas aprovadas sejam enviadas

// Função para salvar logs de forma formatada (mesma do server.php)
function salvarLog($arquivo, $dados, $tipo = 'INFO') {
    $timestamp = date('Y-m-d H:i:s');
    $logEntry = [
        'timestamp' => $timestamp,
        'tipo' => $tipo,
        'dados' => $dados
    ];
    file_put_contents($arquivo, json_encode($logEntry, JSON_PRETTY_PRINT) . PHP_EOL, FILE_APPEND);
}

// Verifica se o script está sendo executado via navegador ou terminal
$isCli = (php_sapi_name() === 'cli');
if (!$isCli) {
    // Proteger acesso via navegador com um token simples
    $accessToken = '123456789'; // Você pode alterar este token para um mais seguro
    if (!isset($_GET['token']) || $_GET['token'] !== $accessToken) {
        http_response_code(403);
        die('Acesso não autorizado');
    }
}

// Log do início da verificação
salvarLog('sync_utmify.log', 'Iniciando verificação de vendas não sincronizadas com UTMify', 'INICIO');

// Encontrar todos os arquivos de status de pagamento
$statusFiles = glob('status_pagamento_*.txt');
$vendas_verificadas = 0;
$vendas_reenviadas = 0;
$vendas_falhas = 0;

// Configuração da API UTMify
$urlUtmify = 'https://api.utmify.com.br/api-credentials/orders';
$tokenUtmify = 'XRMZ5DcMj6ECZqBD2k34Pke01hnDP9lYpl2x';
$headers = [
    'x-api-token: ' . $tokenUtmify,
    'Content-Type: application/json'
];

// Verificar cada arquivo de status
foreach ($statusFiles as $statusFile) {
    // Extrair ID do pedido do nome do arquivo
    preg_match('/status_pagamento_(.+)\.txt/', $statusFile, $matches);
    if (empty($matches[1])) continue;
    
    $customId = $matches[1];
    $status = trim(file_get_contents($statusFile));
    $vendas_verificadas++;
    
    // Verificar se o status é aprovado
    $isApproved = strtoupper($status) === 'APPROVED' || 
                  strtoupper($status) === 'PAID' || 
                  strtoupper($status) === 'COMPLETE' || 
                  strtoupper($status) === 'COMPLETED';
    
    if ($isApproved) {
        // Verificar se já foi enviado com sucesso para UTMify
        $enviado = false;
        $logFile = "sync_status_{$customId}.json";
        
        if (file_exists($logFile)) {
            $logContent = json_decode(file_get_contents($logFile), true);
            $enviado = isset($logContent['enviado']) && $logContent['enviado'] === true;
        }
        
        // Se não foi enviado ainda, reenviar para UTMify
        if (!$enviado) {
            // Verificar se temos o webhook original
            $webhookFile = "webhook_{$customId}.json";
            if (file_exists($webhookFile)) {
                $webhookData = json_decode(file_get_contents($webhookFile), true);
                
                // Forçar status como aprovado
                $webhookData['status'] = 'APPROVED';
                
                // BUSCA AVANÇADA DOS PARÂMETROS UTM
                // Vamos procurar o arquivo específico de UTM para este lead em vários locais possíveis
                $utmParams = [
                    'utm_source' => '',
                    'utm_campaign' => '',
                    'utm_medium' => '',
                    'utm_content' => '',
                    'utm_term' => '',
                    'utm_id' => '',
                    'fbclid' => ''
                ];
                
                // Lista de possíveis localizações do arquivo UTM
                $possiveisArquivosUtm = [
                    "utm_params_{$customId}.json",
                    __DIR__ . "/utm_params_{$customId}.json",
                    __DIR__ . "/confirmacao/pagamento/utm_params_{$customId}.json"
                ];
                
                // Adicionar busca por qualquer arquivo utm_params que existe no diretório atual
                $arquivosUtmGlob = glob('utm_params_*.json');
                $possiveisArquivosUtm = array_merge($possiveisArquivosUtm, $arquivosUtmGlob);
                
                // Adicionar busca no diretório de confirmação de pagamento
                $arquivosUtmGlobConfirmacao = glob(__DIR__ . '/confirmacao/pagamento/utm_params_*.json');
                $possiveisArquivosUtm = array_merge($possiveisArquivosUtm, $arquivosUtmGlobConfirmacao);
                
                $utmArquivoEncontrado = null;
                $arquivosExistentes = [];
                
                // Encontrar todos os arquivos que existem
                foreach ($possiveisArquivosUtm as $utmFile) {
                    if (file_exists($utmFile)) {
                        $arquivosExistentes[] = [
                            'arquivo' => $utmFile,
                            'modificado' => filemtime($utmFile)
                        ];
                    }
                }
                
                // Ordenar arquivos pelo mais recente
                usort($arquivosExistentes, function($a, $b) {
                    return $b['modificado'] - $a['modificado'];
                });
                
                // Pegar o arquivo mais recente, se existir
                if (!empty($arquivosExistentes)) {
                    $utmArquivoEncontrado = $arquivosExistentes[0]['arquivo'];
                    
                    // Carregar os parâmetros UTM do arquivo
                    $utmFileContent = file_get_contents($utmArquivoEncontrado);
                    $utmParamsFromFile = json_decode($utmFileContent, true);
                    
                    if (is_array($utmParamsFromFile)) {
                        // Usar os parâmetros UTM do arquivo
                        $utmParams = array_merge($utmParams, $utmParamsFromFile);
                        salvarLog('sync_utmify.log', [
                            'arquivo_utm' => basename($utmArquivoEncontrado),
                            'utm_source' => $utmParams['utm_source'] ?? '',
                            'utm_campaign' => $utmParams['utm_campaign'] ?? '',
                            'customId' => $customId
                        ], 'UTM_CARREGADO');
                    } else {
                        salvarLog('sync_utmify.log', "Erro ao decodificar parâmetros UTM do arquivo $utmArquivoEncontrado", 'ERRO');
                    }
                } else {
                    // Se não encontrou o arquivo, tentar extrair da URL de confirmação
                    $confirmationUrl = $webhookData['confirmationUrl'] ?? '';
                    if (!empty($confirmationUrl)) {
                        $queryString = parse_url($confirmationUrl, PHP_URL_QUERY);
                        parse_str($queryString, $queryParams);
                        
                        // Extrair parâmetros UTM da URL
                        foreach ($utmParams as $key => $value) {
                            if (isset($queryParams[$key])) {
                                $utmParams[$key] = $queryParams[$key];
                            }
                        }
                    }
                }
                
                // Se utm_source for vazio, usar 'direct'
                if (empty($utmParams['utm_source'])) {
                    $utmParams['utm_source'] = 'direct';
                }
                
                // Gerar identificador único para sck se utm_id estiver vazio
                if (empty($utmParams['utm_id']) && (!empty($utmParams['utm_campaign']) || !empty($utmParams['utm_content']))) {
                    if (!empty($utmParams['utm_campaign'])) {
                        $utmParams['utm_id'] = md5($utmParams['utm_campaign'] . $utmParams['utm_source']);
                    } elseif (!empty($utmParams['utm_content'])) {
                        $utmParams['utm_id'] = md5($utmParams['utm_content'] . $utmParams['utm_source']);
                    }
                }
                
                // Log dos parâmetros UTM finais
                salvarLog('sync_utmify.log', [
                    'utm_source' => $utmParams['utm_source'],
                    'utm_campaign' => $utmParams['utm_campaign'],
                    'utm_medium' => $utmParams['utm_medium'],
                    'utm_content' => $utmParams['utm_content'],
                    'utm_id' => $utmParams['utm_id'],
                    'customId' => $customId
                ], 'UTM_FINAL');
                
                // Montar os dados para a UTMify
                $dadosUtmify = [
                    'orderId' => $customId,
                    'platform' => 'GhostPay',
                    'paymentMethod' => 'pix',
                    'status' => 'paid',
                    'createdAt' => $webhookData['createdAt'] ?? date('Y-m-d H:i:s'),
                    'approvedDate' => $webhookData['approvedAt'] ?? date('Y-m-d H:i:s'),
                    'totalInCents' => $webhookData['totalValue'] ?? 5990,
                    'refundedAt' => null,
                    'customer' => [
                        'name' => isset($webhookData['customer']) ? ($webhookData['customer']['name'] ?? '') : '',
                        'email' => isset($webhookData['customer']) ? ($webhookData['customer']['email'] ?? '') : '',
                        'phone' => isset($webhookData['customer']) ? ($webhookData['customer']['phone'] ?? '') : '',
                        'document' => isset($webhookData['customer']) ? ($webhookData['customer']['cpf'] ?? $webhookData['customer']['document'] ?? '') : '',
                        'country' => 'BR',
                        'ip' => '127.0.0.1'
                    ],
                    'products' => [
                        [
                            'id' => 'taxinha_do_amor',
                            'name' => 'Taxinha do amor',
                            'planId' => null,
                            'planName' => null,
                            'quantity' => 1,
                            'priceInCents' => $webhookData['totalValue'] ?? 5990
                        ]
                    ],
                    'trackingParameters' => [
                        'src' => $utmParams['utm_source'],
                        'sck' => $utmParams['utm_id'],
                        'utm_source' => $utmParams['utm_source'],
                        'utm_campaign' => $utmParams['utm_campaign'],
                        'utm_medium' => $utmParams['utm_medium'],
                        'utm_content' => $utmParams['utm_content'],
                        'utm_term' => $utmParams['utm_term'],
                        'utm_id' => $utmParams['utm_id'],
                        'fbclid' => $utmParams['fbclid']
                    ],
                    'commission' => [
                        'totalPriceInCents' => $webhookData['totalValue'] ?? 5990,
                        'gatewayFeeInCents' => isset($webhookData['totalValue']) && isset($webhookData['netValue']) ? 
                            ($webhookData['totalValue'] - $webhookData['netValue']) : 0,
                        'userCommissionInCents' => $webhookData['netValue'] ?? ($webhookData['totalValue'] ?? 5990)
                    ],
                    'isTest' => false
                ];
                
                // Salvar cópia dos dados que serão enviados para UTMify
                file_put_contents("utmify_dados_{$customId}.json", json_encode($dadosUtmify, JSON_PRETTY_PRINT));
                
                // Tentativa de envio para UTMify original
                $ch = curl_init($urlUtmify);
                curl_setopt($ch, CURLOPT_POST, true);
                curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($dadosUtmify));
                curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
                curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
                curl_setopt($ch, CURLOPT_TIMEOUT, 30);
                
                $response = curl_exec($ch);
                $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
                $error = curl_error($ch);
                
                curl_close($ch);
                
                // Verificar se o envio foi bem-sucedido
                $success = ($httpCode >= 200 && $httpCode < 300);
                
                // Se falhou, tentar a API alternativa
                if (!$success) {
                    $urlUtmifyAlt = 'https://api.utmify.io/api/orders/create';
                    
                    $ch = curl_init($urlUtmifyAlt);
                    curl_setopt($ch, CURLOPT_POST, true);
                    curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($dadosUtmify));
                    curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
                    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
                    curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
                    curl_setopt($ch, CURLOPT_TIMEOUT, 30);
                    
                    $responseAlt = curl_exec($ch);
                    $httpCodeAlt = curl_getinfo($ch, CURLINFO_HTTP_CODE);
                    $errorAlt = curl_error($ch);
                    
                    curl_close($ch);
                    
                    // Atualizar status de sucesso
                    $success = ($httpCodeAlt >= 200 && $httpCodeAlt < 300);
                    
                    if ($success) {
                        $httpCode = $httpCodeAlt;
                        $response = $responseAlt;
                        $error = $errorAlt;
                    }
                }
                
                // Registrar tentativa de envio
                $logData = [
                    'customId' => $customId,
                    'enviado' => $success,
                    'timestamp' => date('Y-m-d H:i:s'),
                    'httpCode' => $httpCode,
                    'response' => $response,
                    'error' => $error
                ];
                
                file_put_contents($logFile, json_encode($logData, JSON_PRETTY_PRINT));
                
                if ($success) {
                    $vendas_reenviadas++;
                    salvarLog('sync_utmify.log', [
                        'customId' => $customId,
                        'status' => 'Reenvio bem-sucedido para UTMify',
                        'utm_source' => $utmParams['utm_source'],
                        'utm_campaign' => $utmParams['utm_campaign']
                    ], 'REENVIO_SUCESSO');
                } else {
                    $vendas_falhas++;
                    salvarLog('sync_utmify.log', [
                        'customId' => $customId,
                        'status' => 'Falha no reenvio para UTMify',
                        'erro' => $error,
                        'httpCode' => $httpCode
                    ], 'REENVIO_FALHA');
                }
            } else {
                // Webhook original não encontrado
                salvarLog('sync_utmify.log', [
                    'customId' => $customId,
                    'status' => 'Webhook original não encontrado'
                ], 'WEBHOOK_NAO_ENCONTRADO');
            }
        }
    }
}

// Resumo da operação
$resumo = [
    'vendas_verificadas' => $vendas_verificadas,
    'vendas_reenviadas' => $vendas_reenviadas,
    'vendas_falhas' => $vendas_falhas,
    'timestamp' => date('Y-m-d H:i:s')
];

salvarLog('sync_utmify.log', $resumo, 'RESUMO');

// Saída para o usuário
if ($isCli) {
    echo "Verificação concluída!\n";
    echo "Vendas verificadas: {$vendas_verificadas}\n";
    echo "Vendas reenviadas: {$vendas_reenviadas}\n";
    echo "Falhas de reenvio: {$vendas_falhas}\n";
} else {
    header('Content-Type: application/json');
    echo json_encode($resumo);
}
