<?php
// Definir cabeçalhos CORS para permitir requisições de qualquer origem
header('Access-Control-Allow-Origin: *');
header('Access-Control-Allow-Methods: GET, POST, OPTIONS');
header('Access-Control-Allow-Headers: Content-Type');
header('Content-Type: application/json');

// Log para depuração
error_log("Verificação de status iniciada. Request URI: " . $_SERVER['REQUEST_URI']);
error_log("Parâmetros GET: " . print_r($_GET, true));

// Modificação: Extrair o ID da transação de forma mais robusta
$transactionId = null;
if ($_SERVER["REQUEST_METHOD"] == "GET") {
    // Verifica se o ID está presente nos parâmetros GET
    if (isset($_GET['id'])) {
        $transactionId = $_GET['id'];
        
        // Garantir que o ID seja limpo de quaisquer parâmetros extras
        $transactionId = preg_replace('/[&?].*$/', '', $transactionId);
        
        // Remover caracteres não alfanuméricos (uma precaução adicional)
        $transactionId = preg_replace('/[^a-zA-Z0-9\-]/', '', $transactionId);
        
        // Log do ID limpo
        error_log("ID da transação limpo: " . $transactionId);
    }
}

if ($transactionId) {
    // URL da API para verificar o status do pagamento
    $apiUrl = "https://app.ghostspaysv1.com/api/v1/transaction.getpayment?id=" . urlencode($transactionId);
    $apiKey = "e4d47ac1-f59c-4560-88bf-16763cb6e93f"; // Substitua pela sua chave de API

    error_log("Consultando API com URL: " . $apiUrl);

    // Inicializa o cURL
    $ch = curl_init($apiUrl);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_HTTPHEADER, [
        "Authorization: " . $apiKey
    ]);

    // Executa a requisição
    $response = curl_exec($ch);
    $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    $curlError = curl_error($ch);
    curl_close($ch);

    error_log("Resposta da API (HTTP $httpCode): " . $response);
    if ($curlError) {
        error_log("Erro cURL: " . $curlError);
    }

    // Verifica se a requisição foi bem-sucedida
    if ($httpCode == 200) {
        $responseData = json_decode($response, true);

        // Retorna o status do pagamento em formato JSON
        echo json_encode(['status' => $responseData['status']]);
    } else {
        // Retorna um erro em formato JSON
        echo json_encode(['status' => 'ERROR', 'message' => 'Erro ao verificar status do pagamento.']);
    }
} else {
    // Retorna um erro em formato JSON se o método não for GET ou o ID não for fornecido
    echo json_encode(['status' => 'INVALID_REQUEST', 'message' => 'Requisição inválida. ID não fornecido.']);
}
?>